<?php
include('mysqli_connect.php');

// Check if 'min_price' and 'max_price' are provided in the URL query and are not empty
if (!isset($_GET['min_price']) || !isset($_GET['max_price']) || trim($_GET['min_price']) === '' || trim($_GET['max_price']) === '') {
    echo "<p style='color: red;'>Please enter both minimum and maximum price values to search for products.</p>";
    exit();
}

// Retrieve and sanitize the input values
$min_price = (float)mysqli_real_escape_string($dbc, trim($_GET['min_price']));
$max_price = (float)mysqli_real_escape_string($dbc, trim($_GET['max_price']));

// Validate that min_price is less than or equal to max_price
if ($min_price > $max_price) {
    echo "<p style='color: red;'>Minimum price cannot be greater than maximum price. Please try again.</p>";
    exit();
}

// Construct the SQL query to fetch products within the specified price range
$query = "SELECT * FROM product WHERE price BETWEEN $min_price AND $max_price";

// Execute the query and store the result set
$result = mysqli_query($dbc, $query);

// Check if any products were found: Reference: https://www.php.net/manual/en/mysqli-result.num-rows.php
if (mysqli_num_rows($result) > 0) {
    echo "<div style='display: flex; flex-direction: column; gap: 20px; background-color: #a9a9a9; padding: 20px;'>";

    // Loop through each row in the query result
    while ($row = mysqli_fetch_assoc($result)) {
        echo "<div style='display: flex; align-items: center; gap: 20px; border: 1px solid #ccc; padding: 15px; background-color: #ffffff;'>";

        // Display the product's image
        echo "<div>";
        echo "<img src='" . htmlspecialchars($row['image_url']) . "' alt='" . htmlspecialchars($row['name']) . "' style='width: 400px; height: 300px; margin-right: 20px;'>";
        echo "</div>";

        // Display the product's details
        echo "<div>";
        echo "<h3 style='margin: 0;'>" . htmlspecialchars($row['name']) . "</h3>";
        echo "<p><strong>Category:</strong> " . htmlspecialchars($row['category']) . "</p>";
        echo "<p><strong>Price:</strong> $" . htmlspecialchars($row['price']) . "</p>";
        echo "<p><strong>Quantity:</strong> " . htmlspecialchars($row['quantity']) . "</p>";
        echo "<p><strong>Description:</strong> " . htmlspecialchars($row['description']) . "</p>";
        echo "</div>";

        echo "</div>"; // Close product container
    }

    echo "</div>"; // Close main container
} else {
    // Display a message if no products are found
    echo "<p style='color: red;'>No products found within the price range of <strong>$" . htmlspecialchars($min_price) . "</strong> to <strong>$" . htmlspecialchars($max_price) . "</strong>.</p>";
}
?>

